@@ -155,9 +155,13 @@ API_VERSION = '1.0.0'
 AUTH_HELPER, SECURITY_CONTEXT = None, None
 JOB_ID, WORKSPACE_ID, PROJECT_CONTEXT_ID = None, None, None
 
-APISERVER_PROTOCOL = 'https'
-APISERVER_HOST = 'api.dnanexus.com'
-APISERVER_PORT = '443'
+DEFAULT_APISERVER_PROTOCOL = 'https'
+DEFAULT_APISERVER_HOST = 'api.dnanexus.com'
+DEFAULT_APISERVER_PORT = '443'
+
+APISERVER_PROTOCOL = DEFAULT_APISERVER_PROTOCOL
+APISERVER_HOST = DEFAULT_APISERVER_HOST
+APISERVER_PORT = DEFAULT_APISERVER_PORT
 
 SESSION_HANDLERS = collections.defaultdict(requests.session)
 
