@@ -1059,6 +1059,7 @@ class TestDXSearch(unittest.TestCase):
     def test_find_jobs(self):
         dxapplet = dxpy.DXApplet()
         dxapplet.new(name="test_applet",
+                     dxapi="1.0.0",
                      inputSpec=[{"name": "chromosomes", "class": "record"},
                                 {"name": "rowFetchChunk", "class": "int"}
                                 ],
@@ -1071,12 +1072,13 @@ class TestDXSearch(unittest.TestCase):
         prog_input = {"chromosomes": {"$dnanexus_link": dxrecord.get_id()},
                       "rowFetchChunk": 100}
         dxjob = dxapplet.run(applet_input=prog_input)
-        results = list(dxpy.find_jobs(launched_by='user-000000000000000000000000',
-                                      applet=dxapplet,
+        me = dxpy.user_info()['userId']
+        results = list(dxpy.find_jobs(launched_by=me,
+                                      executable=dxapplet,
                                       project=dxapplet.get_proj_id(),
                                       origin_job=dxjob.get_id(),
-                                      parent_job=None,
-                                      modified_after=0,
+                                      parent_job='none',
+                                      created_after='-15s',
                                       describe=True))
         self.assertEqual(len(results), 1)
         result = results[0]
